@@ -122,7 +122,8 @@ CCanvas::CCanvas()
     labelZoom->setText("zoom ---");
 
     // Database connection one time
-    QDir path( QCoreApplication::applicationDirPath() );
+    //QDir path( QCoreApplication::applicationDirPath() );
+    QDir path( QDir::homePath() );
     dbName = path.filePath("qlandkarte.db");
 
     db = QSqlDatabase::addDatabase("QSQLITE","qlandkarte");
